import 'dart:async';
import 'dart:math';

import 'package:flutter/services.dart';

class GreatCircleDistance {
  static const MethodChannel _channel = MethodChannel('great_circle_distance');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// [_earthRadius] Radius of the Earch in km.
  static const double _earthRadius = 6378.1370;

  static Future<double?> calculate({
    required double? lat1,
    required double? lon1,
    required double? lat2,
    required double? lon2,
  }) async {
    if (lat1 == null || lon1 == null || lat2 == null || lon2 == null) {
      return null;
    }
    // Great circle distance by Spherical Law of Cosines
    final double _lat1 = _radiansFromDegrees(lat1);
    final double _lat2 = _radiansFromDegrees(lat2);
    final double _aLon = _radiansFromDegrees(lon2 - lon1);
    final double _d =
        acos(sin(_lat1) * sin(_lat2) + cos(_lat1) * cos(_lat2) * cos(_aLon));
    return _earthRadius * _d;
  }

  static double _radiansFromDegrees(final double degrees) =>
      degrees * (pi / 180.0);
}
